All Classes and Interfaces

Class
Description
The resource with the name requested already exists.
 
An AWS Arn.
 
 
 
 
 
The specified client token has already been used in another resource request.
 
Service client for accessing CloudControlApi asynchronously.
A builder for creating an instance of CloudControlAsyncClient.
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the resource will never enter into the desired state.
 
 
The parameters object used to resolve the auth schemes for the CloudControl service.
An auth scheme provider for CloudControl service.
This includes configuration specific to CloudControlApi that is supported by both CloudControlClientBuilder and CloudControlAsyncClientBuilder.
Service client for accessing CloudControlApi.
A builder for creating an instance of CloudControlClient.
 
The parameters object used to resolve an endpoint for the CloudControl service.
 
An endpoint provider for CloudControl.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the resource will never enter into the desired state.
 
The resource is currently being modified by another operation.
 
Another resource operation is currently being performed on this resource.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
The resource handler has returned that the downstream service generated an error that doesn't map to any other handler error code.
 
 
 
 
 
 
 
 
 
 
The resource handler has failed without a returning a more specific error code.
 
The resource handler has returned that an unexpected error occurred within the resource handler.
 
Represents the current status of applicable Hooks for a resource operation request.
 
Identifiers for variables declared within the rule engine, e.g.
The resource handler has returned that the credentials provided by the user are invalid.
 
The resource handler has returned that invalid input from the user has generated a generic exception.
 
 
An intermediate value for JMESPath expressions, encapsulating the different data types supported by JMESPath and the operations on that data.
 
 
 
 
 
 
 
 
The resource handler has returned that the request couldn't be completed due to networking issues, such as a failure to receive a response from the server.
 
The resource handler has returned that the downstream resource failed to complete all of its ready-state checks.
 
One or more properties included in this resource operation are defined as create-only, and therefore can't be updated.
 
 
 
 
 
 
 
 
 
 
 
Cloud Control API hasn't received a valid response from the resource handler, due to a configuration error.
 
Represents the current status of a resource operation request.
 
 
 
A resource operation with the specified request token can't be found.
 
The resource is temporarily unavailable to be acted upon.
 
Represents information about a provisioned resource.
 
A resource with the specified identifier can't be found.
 
The filter criteria to use in determining the requests returned.
 
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
The resource handler has returned that the downstream service returned an internal error, typically with a 5XX HTTP status code.
 
The resource handler has returned that a non-transient resource limit was reached on the service side.
 
 
The request was denied due to request throttling.
 
The specified extension doesn't exist in the CloudFormation registry.
 
The specified resource doesn't support this resource operation.
 
 
 
 
 
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.
Contains classes used at runtime by the code generator classes for waiter acceptors generated from JMESPath expressions.
A WaiterAcceptor implementation that checks for a specific HTTP response status, regardless of whether it's reported by a response or an exception.