Class UpdateResourceRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<UpdateResourceRequest.Builder,UpdateResourceRequest>

@Generated("software.amazon.awssdk:codegen") public final class UpdateResourceRequest extends CloudControlRequest implements ToCopyableBuilder<UpdateResourceRequest.Builder,UpdateResourceRequest>
  • Method Details

    • typeName

      public final String typeName()

      The name of the resource type.

      Returns:
      The name of the resource type.
    • typeVersionId

      public final String typeVersionId()

      For private resource types, the type version to use in this resource operation. If you do not specify a resource version, CloudFormation uses the default version.

      Returns:
      For private resource types, the type version to use in this resource operation. If you do not specify a resource version, CloudFormation uses the default version.
    • roleArn

      public final String roleArn()

      The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role for Cloud Control API to use when performing this resource operation. The role specified must have the permissions required for this operation. The necessary permissions for each event handler are defined in the handlers section of the resource type definition schema.

      If you do not specify a role, Cloud Control API uses a temporary session created using your Amazon Web Services user credentials.

      For more information, see Specifying credentials in the Amazon Web Services Cloud Control API User Guide.

      Returns:
      The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role for Cloud Control API to use when performing this resource operation. The role specified must have the permissions required for this operation. The necessary permissions for each event handler are defined in the handlers section of the resource type definition schema.

      If you do not specify a role, Cloud Control API uses a temporary session created using your Amazon Web Services user credentials.

      For more information, see Specifying credentials in the Amazon Web Services Cloud Control API User Guide.

    • clientToken

      public final String clientToken()

      A unique identifier to ensure the idempotency of the resource request. As a best practice, specify this token to ensure idempotency, so that Amazon Web Services Cloud Control API can accurately distinguish between request retries and new resource requests. You might retry a resource request to ensure that it was successfully received.

      A client token is valid for 36 hours once used. After that, a resource request with the same client token is treated as a new request.

      If you do not specify a client token, one is generated for inclusion in the request.

      For more information, see Ensuring resource operation requests are unique in the Amazon Web Services Cloud Control API User Guide.

      Returns:
      A unique identifier to ensure the idempotency of the resource request. As a best practice, specify this token to ensure idempotency, so that Amazon Web Services Cloud Control API can accurately distinguish between request retries and new resource requests. You might retry a resource request to ensure that it was successfully received.

      A client token is valid for 36 hours once used. After that, a resource request with the same client token is treated as a new request.

      If you do not specify a client token, one is generated for inclusion in the request.

      For more information, see Ensuring resource operation requests are unique in the Amazon Web Services Cloud Control API User Guide.

    • identifier

      public final String identifier()

      The identifier for the resource.

      You can specify the primary identifier, or any secondary identifier defined for the resource type in its resource schema. You can only specify one identifier. Primary identifiers can be specified as a string or JSON; secondary identifiers must be specified as JSON.

      For compound primary identifiers (that is, one that consists of multiple resource properties strung together), to specify the primary identifier as a string, list the property values in the order they are specified in the primary identifier definition, separated by |.

      For more information, see Identifying resources in the Amazon Web Services Cloud Control API User Guide.

      Returns:
      The identifier for the resource.

      You can specify the primary identifier, or any secondary identifier defined for the resource type in its resource schema. You can only specify one identifier. Primary identifiers can be specified as a string or JSON; secondary identifiers must be specified as JSON.

      For compound primary identifiers (that is, one that consists of multiple resource properties strung together), to specify the primary identifier as a string, list the property values in the order they are specified in the primary identifier definition, separated by |.

      For more information, see Identifying resources in the Amazon Web Services Cloud Control API User Guide.

    • patchDocument

      public final String patchDocument()

      A JavaScript Object Notation (JSON) document listing the patch operations that represent the updates to apply to the current resource properties. For details, see Composing the patch document in the Amazon Web Services Cloud Control API User Guide.

      Returns:
      A JavaScript Object Notation (JSON) document listing the patch operations that represent the updates to apply to the current resource properties. For details, see Composing the patch document in the Amazon Web Services Cloud Control API User Guide.
    • toBuilder

      public UpdateResourceRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<UpdateResourceRequest.Builder,UpdateResourceRequest>
      Specified by:
      toBuilder in class CloudControlRequest
    • builder

      public static UpdateResourceRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends UpdateResourceRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo