Waiter utility class that polls a resource until a desired state is reached or until it is determined that the
resource will never enter into the desired state.
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the
resource will never enter into the desired state.
The resource handler has returned that the request couldn't be completed due to networking issues, such as a failure
to receive a response from the server.